﻿using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Drawing;
using System.Linq;
using System.Text;
using Infragistics.Win;
using Infragistics.Win.UltraWinGrid;

namespace WG_CheckBoxHeaderWithGroupByRows
{
    class CustomCreationFilter : IUIElementCreationFilter
    {
        public EventHandler<GroupByRowCheckBoxClickedEventArgs> GroupByRowCheckBoxClicked;
        private string _columnKey;

        public CustomCreationFilter(string columnKey)
        {
            this._columnKey = columnKey;
        }

        public void AfterCreateChildElements(UIElement parent)
        {
            if (parent is GroupByRowUIElement)
            {
                var rowUIElement = parent as GroupByRowUIElement;
                var groupDescElement = parent.GetDescendant(typeof(GroupByRowDescriptionUIElement));
                CheckBoxUIElement checkBoxEl;
                //check if the row contains any rows and if it has the desired column
                if (!(rowUIElement.GroupByRow.Rows.Count > 0 &&
                    rowUIElement.GroupByRow.Rows[0].Cells != null && 
                    rowUIElement.GroupByRow.Rows[0].Cells.Cast<UltraGridCell>().Any(c => c.Column.Key == _columnKey)))
                    return;
                
                if (rowUIElement.GroupByRow.Tag != null)
                {
                    checkBoxEl = (CheckBoxUIElement)rowUIElement.GroupByRow.Tag;
                }
                else
                {
                    checkBoxEl = new CheckBoxUIElement(rowUIElement);
                    rowUIElement.GroupByRow.Tag = checkBoxEl;
                    checkBoxEl.ElementClick += checkBoxEl_ElementClick;
                }
                checkBoxEl.Rect = new Rectangle(groupDescElement.Rect.Location, 
                    new Size(groupDescElement.Rect.Height, groupDescElement.Rect.Height));
                groupDescElement.Rect = new Rectangle(checkBoxEl.Rect.Right, checkBoxEl.Rect.Top,
                    groupDescElement.Rect.Width - checkBoxEl.Rect.Width, groupDescElement.Rect.Height);
                parent.ChildElements.Add(checkBoxEl);

            }
        }

        void checkBoxEl_ElementClick(object sender, UIElementEventArgs e)
        {
            //don't handle the events inside the filter as it may cause memory leaks
            if (GroupByRowCheckBoxClicked != null)
            {
                GroupByRowCheckBoxClicked(sender, new GroupByRowCheckBoxClickedEventArgs(e.Element));
            }
        }

        public bool BeforeCreateChildElements(UIElement parent)
        {
            return false;
        }
    }


}
